package org.greenstone.gatherer.file;

import org.greenstone.gatherer.collection.CollectionManager;
import org.greenstone.gatherer.file.FileNode;
import org.greenstone.gatherer.util.SynchronizedTreeModelTools;


public class WorkspaceTreeModel
    extends FileSystemModel {

    static private FileNode workspace_tree_root = null;
    static private WorkspaceTreeModel workspace_tree_model = null;
    static private FileNode[] collection_specific_mappings = null;


    public WorkspaceTreeModel(FileNode root)
    {
	super(root);
    }


    static public WorkspaceTreeModel getWorkspaceTreeModel()
    {
	// Create a root node to contain the various nodes in the workspace tree
 	workspace_tree_root = new FileNode("ABS_ROOT");
	workspace_tree_model = new WorkspaceTreeModel(workspace_tree_root);

	// Add the Greenstone Collections mapping
	workspace_tree_root.insert(CollectionManager.getGreenstoneCollectionsMapping());

	// Add the local filespace
	workspace_tree_root.insert(FileSystem.getLocalFileSystem());

	// Add a mapping to the user home folder
	workspace_tree_root.insert(FileSystem.getUserHomeMapping());

	// If mirroring is enabled show the public and private caches
//  	if (Gatherer.config.get("workflow.mirror", false)) {
//  	    // Add Public workspace
//  	    FileNode public_root = new FileNode(new File(Utility.CACHE_DIR), Dictionary.get("Tree.Public"));
//  	    workspace_root.insert(public_root);
//  	    // Add Private workspace if a collection has been loaded.
//  	    if(ready()) {
//  		FileNode private_root = new FileNode(new File(getCollectionCache()), Dictionary.get("Tree.Private"));
//  		workspace_root.insert(private_root);
//  	    }
//  	}

	// Add any collection specific mappings
	collection_specific_mappings = CollectionManager.getCollectionSpecificMappings();
	if (collection_specific_mappings != null) {
	    for (int i = 0; i < collection_specific_mappings.length; i++) {
		SynchronizedTreeModelTools.insertNodeInto(workspace_tree_model,
							  workspace_tree_root,
							  collection_specific_mappings[i]);
	    }
	}

 	return workspace_tree_model;
    }


    static public void refreshCollectionSpecificMappings()
    {
	// Remove all the old collection specific mappings
	if (collection_specific_mappings != null) {
	    for (int i = 0; i < collection_specific_mappings.length; i++) {
		SynchronizedTreeModelTools.removeNodeFromParent(workspace_tree_model,
								collection_specific_mappings[i]);
	    }
	}

	// Add the current collection specific mappings
	collection_specific_mappings = CollectionManager.getCollectionSpecificMappings();
	if (collection_specific_mappings != null) {
	    for (int i = 0; i < collection_specific_mappings.length; i++) {
		SynchronizedTreeModelTools.insertNodeInto(workspace_tree_model,
							  workspace_tree_root,
							  collection_specific_mappings[i]);
	    }
	}
    }
}
