package org.greenstone.gatherer.gui.tree;

import java.io.File;
import java.util.Enumeration;
import javax.swing.tree.TreePath;
import org.greenstone.gatherer.Gatherer;
import org.greenstone.gatherer.file.FileNode;
import org.greenstone.gatherer.file.FileSystemModel;
import org.greenstone.gatherer.file.WorkspaceTreeModel;
import org.greenstone.gatherer.util.Utility;


public class WorkspaceTree
    extends DragTree {

    static public int MAPPED_DIRECTORIES_CHANGED = 11;


    public WorkspaceTree(String name) {
	super(name, WorkspaceTreeModel.getWorkspaceTreeModel(), null, true);
    }


    public void refresh(int refresh_reason) {
	System.err.print("WorkspaceTree::refresh()... ");

	// A collection has been opened/closed - reload the workspace tree model
	if (refresh_reason == DragTree.COLLECTION_CHANGED) {
	    System.err.println("Reason: collection changed.");
	    setModel(WorkspaceTreeModel.getWorkspaceTreeModel());
	}

	// The collection's contents have changed - refresh expanded parts of the collection
	if (refresh_reason == DragTree.COLLECTION_CONTENTS_CHANGED) {
	    System.err.println("Reason: collection contents changed.");

	    String import_directory_str = Gatherer.c_man.getCollectionImport();

	    TreePath tree_root_path = new TreePath(getModel().getRoot());
	    Enumeration expanded_tree_paths = getExpandedDescendants(tree_root_path);
	    while (expanded_tree_paths.hasMoreElements()) {
		TreePath expanded_tree_path = (TreePath) expanded_tree_paths.nextElement();
		FileNode tree_node = (FileNode) expanded_tree_path.getLastPathComponent();

		File tree_node_file = tree_node.getFile();
		if (tree_node_file == null) {
		    continue;
		}

		// Get the path of the open tree node
		String tree_node_path_str = tree_node_file.toString();
		if (!tree_node_path_str.endsWith(File.separator)) {
		    tree_node_path_str = tree_node_path_str + File.separator;
		}

		// If the collection import directory is open, it must be refreshed
		if (tree_node_path_str.equals(import_directory_str)) {
		    System.err.println("Must refresh collection import directory!");
		    ((FileSystemModel) getModel()).refresh(expanded_tree_path);
		}
	    }
	}

	// The method for displaying the tree has changed - redraw the tree
	if (refresh_reason == DragTree.TREE_DISPLAY_CHANGED) {
	    System.err.println("Reason: tree display changed.");
	    updateUI();
	}

	// The collection specific mapped directories have changed - refresh only them
	if (refresh_reason == WorkspaceTree.MAPPED_DIRECTORIES_CHANGED) {
	    System.err.println("Reason: mapped directories changed.");
	    WorkspaceTreeModel.refreshCollectionSpecificMappings();
	}
    }
}
